@@ -2,13 +2,45 @@
 #       misc - miscellaneaous functions
 #
 #	$RCSfile: misc.pl,v $
-#	$Revision: 2.0 $
+#	$Revision: 2.1 $
 #	$Author: ripe-dbm $
-#	$Date: 1996/08/08 10:47:30 $
+#	$Date: 1996/08/14 15:46:06 $
 #
 
 require "defines.pl";
 
+sub sortchangedfield {
+    
+    $a=~ /(\d{6,6})$/;
+    local($date1)=$1;
+    
+    $b=~ /(\d{6,6})$/;
+    
+    # print STDERR "-$a-$b-$date1-$1-\n";
+      
+    if ((!$date1) && (!$1)) {
+       
+       return 0;
+       
+    }
+    elsif (!$date1) {
+       
+       return -1;
+       
+    }
+    elsif (!$1) {
+       
+       return 1;
+       
+    }
+    else {
+       
+       return $date1 <=> $1;
+    
+    }
+    
+}
+
 sub ReplaceGlobalVars {
     local(*text)=@_;
     
