@@ -1,8 +1,8 @@
 
 #	$RCSfile: syntax.pl,v $
-#	$Revision: 2.3 $
-#	$Author: ripe-dbm $
-#	$Date: 1996/08/14 15:45:49 $
+#	$Revision: 2.4 $
+#	$Author: david $
+#	$Date: 1996/08/16 13:00:34 $
 #
 #       ARGUMENTS:      *ASSOC object
 #       RETURNS:        INTEGER object_status
@@ -2083,38 +2083,45 @@ sub dosyntax {
     
        print STDERR "dosyntax - checking rt ($key)\n" if $opt_V; 
        
+       if (($value=~ /^[\d\.]+$/) || ($value=~ /\-/)) {
+          
+          local($newvalue, $code)=&normalizerange($value, "in");
+       
+          print STDERR "dosyntax - newrange: $newvalue code: $code (OK=$O_OK)\n" if ($opt_V);
+       
+          if ($code==$O_OK) {
+             
+             local(@classless)=grep(s/^(\d+)\//&int2quad($1)."\/"/e, &range2prefixes($newvalue));
+             
+             if (scalar(@classless)==1) {
+                $object{$key}=$classless[0];
+                return $O_WARNING, "$ATTL{$key} rewritten to ".$classless[0]." from $value";
+             }
+             else {
+                return $O_ERROR, "$value is not CIDR aligned\nresubmit the following separate objects: ".join(" ", @classless);
+             }
+             
+          }
+          else {
+             
+             if ($value=~ /\-/) {
+                return $O_ERROR, "error in $ATTL{$key}, $value is not a valid IP range";
+             }
+             else {
+                return $O_ERROR, "error in $ATTL{$key}, $value is not a valid classfull A,B or C net";
+             }
+             
+          }
+          
+       }
+       
         local($i) = 0;
 	local($NETMASK) = "[nN]*[eE]*[tT]*[mM][aA][sS][kK]";
 	local($HEX) = "[0-9a-fA-F]";
 	local($HEXMASK) = "0x$HEX$HEX$HEX$HEX$HEX$HEX$HEX$HEX";
 	local($IPADDR) = "\\d+\\.\\d+\\.\\d+\\.\\d+";
-
-	if ($value =~ /^$IPADDR$/) {
-	    local($stat, $msg, @str) = &clasfn_to_netpre($value);
-	    if($stat == $NOK) {
-		return $O_ERROR, "$msg\n";
-	    } else {
-		$object{$key} = $str[0];
-		return $O_WARNING, "$ATTL{$key} re-written to $str[0] from $value\n";
-	    }
-	} elsif ($value =~ /^$IPADDR\s+\-\s+$IPADDR$/) {
-	    local($stat, $msg, @str) = &clasfr_to_netpre($value);
-	    if($stat == $NOK) {
-		return $O_ERROR, "$msg\n";
-	    } else {
-		if($#str >= 1) {
-		    $msg = "$value is not CIDR aligned\n".
-			"resubmit the following seperate objects\n";
-		    foreach $i (0..$#str) {
-			$msg .= "$str[$i]\n";
-		    }
-		    return $O_ERROR, "$msg\n";
-		} else {
-		    $object{$key} = $str[0];
-		    return $O_WARNING, "$ATTL{$key} re-written to $str[0] from $value\n";
-		}
-	    }
-	} elsif ($value =~ /^$IPADDR\s+($NETMASK)*\s*$IPADDR$/ 
+       
+	if ($value =~ /^$IPADDR\s+($NETMASK)*\s*$IPADDR$/ 
 		 || $value =~/^$IPADDR\s+($NETMASK)*\s*$HEXMASK$/) {
 	    local($stat, $msg, @str) = &netmask_to_netpre($value);
 	    if($stat == $NOK) {
