@@ -2,9 +2,9 @@
 #       whoisd - whois Internet daemon
 #
 #	$RCSfile: whoisd.pl,v $
-#	$Revision: 2.0 $
-#	$Author: ripe-dbm $
-#	$Date: 1996/08/08 10:47:30 $
+#	$Revision: 2.3 $
+#	$Author: ambrose $
+#	$Date: 1996/11/08 09:53:39 $
 #
 
 #
@@ -504,7 +504,9 @@ sub whois {
           &Template($output,$opt_t);
        }
        else {
-          print $output "\n% No template available for object \"$opt_t\"";
+# Patch from David, 961010, replaced this; AMRM, 961010
+#          print $output "\n% No template available for object \"$opt_t\"";
+          print $output "\n% No template available for object \"$opt_t\"\n";
        }
 
        return 1;
@@ -860,7 +862,7 @@ sub parse {
     
     while ($string=~ /^-/) {
        
-       if ($string=~ s/^\-([arkFLmMS]+) *//) {
+       if ($string=~ s/^\-(\S*[arkFLmMS]+\S*) *//) {
           
           local($option)=$1;
           
@@ -905,21 +907,55 @@ sub parse {
            
         }
                 
-        if ($string =~ s/^\-(s) +(\S+) *//) {
-            local($src) = $2;
+# Patch from David replaced this, 961010, AMRM.
+#
+#        if ($string =~ s/^\-(s) +(\S+) *//) {
+#            local($src) = $2;
+#
+#            $src=~ tr/a-z/A-Z/;
+#            $src=join(",", split(/\,+/, $src));
+#            
+#            if ($opt_s) {
+#               $opt_s=join(",",$opt_s,$src);
+#            }
+#            else {
+#               $opt_s=$src;
+#            }
+#            
+#            next;
+#        }
+
+	 if ($string =~ s/^\-s +(\S+) *//) {
+            local($src)=$1;
             
             $src=~ tr/a-z/A-Z/;
-            $src=join(",", split(/\,+/, $src));
+            
+            local(@requestedsources)=split(/\,+/, $src);
+            local(@acceptedsources)=grep($DBFILE{$_}, @requestedsources);
+            
+            if (scalar(@requestedsources)!=scalar(@acceptedsources)) {
+               
+               local(@notacceptedsources)=grep(!$DBFILE{$_}, @requestedsources);
+               local($availablesources);
+               ($availablesources=$ALLLOOK) =~ s/ /\,/g;
+               
+               alarm $KEEPOPEN;
+               print $output "\n% Ignored \"".join(",",@notacceptedsources)."\",
+% Choose sources from: \"".$availablesources."\"\n";  
+               &flush($output);
+               
+            }
             
             if ($opt_s) {
-               $opt_s=join(",",$opt_s,$src);
+               $opt_s=join(",",$opt_s,@acceptedsources) if (@acceptedsources);
             }
             else {
-               $opt_s=$src;
+               $opt_s=join(",", @acceptedsources) if (@acceptedsources);
             }
             
             next;
         }
+            
         
         if ($string =~ s/^\-V *([a-zA-Z]+\d+[\d\.]*) *//) {
             $opt_Version=$1;
@@ -941,11 +977,16 @@ sub parse {
                  
               }
               else {
-                 
+# Patch from David replaced the following, 961010, AMRM.                 
+#                 alarm $KEEPOPEN;
+#                 print $output "\n% Request for unknown object type \"$ATTL{$type}\" ignored";  
+#                 &flush($output);
+             	   
+		$type=$ATTL{$type} if ($ATTL{$type});
                  alarm $KEEPOPEN;
-                 print $output "\n% Request for unknown object type \"$ATTL{$type}\" ignored";  
+                 print $output "\n% Request for unknown object type \"$type\" ignored\n";
                  &flush($output);
-              
+
               }
               
            }
@@ -1326,14 +1367,33 @@ sub dowhoislookup {
 
       $result=0;
       
-      if (@ARGV) {
-         $query=join(" ", grep($_ ne "-k", @ARGV));
+
+# Patch from David replaced this, 961010, AMRM
+#
+#      if (@ARGV) {
+#         $query=join(" ", grep($_ ne "-k", @ARGV));
+#      }
+#      else {
+#         alarm $KEEPOPEN;
+#         $query=<$input>;
+#      }
+	
+	$!="";
+      
+      if ((@ARGV) && (!$opt_k)) {
+         $query=join(" ", @ARGV);
       }
       else {
          alarm $KEEPOPEN;
          $query=<$input>;
       }
       
+      print STDERR "($$) dowhoislookup - query: -$query- errorcode: -$!-\n" if (
+$opt_V);
+
+
+# End of patch from David, 961010, AMRM
+      
       alarm $KEEPOPEN;
     
       if ($REPLYBANNER!~ /^\s*$/) {
